import * as React from 'react';
import { List, ListItem, TextLink } from '@contentful/f36-components';
import { ExternalLinkIcon, InfoCircleIcon } from '@contentful/f36-icons';
import { entityHelpers } from '@contentful/field-editor-shared';
import * as styles from './styles';
function UniquenessError(props) {
    const [state, setState] = React.useState({
        loading: true,
        entries: []
    });
    const contentTypesById = React.useMemo(()=>props.space.getCachedContentTypes().reduce((prev, ct)=>({
                ...prev,
                [ct.sys.id]: ct
            }), {}), [
        props.space
    ]);
    const getTitle = React.useCallback((entry)=>entityHelpers.getEntryTitle({
            entry,
            defaultTitle: 'Untitled',
            localeCode: props.localeCode,
            defaultLocaleCode: props.defaultLocaleCode,
            contentType: contentTypesById[entry.sys.contentType.sys.id]
        }), [
        props.localeCode,
        props.defaultLocaleCode,
        contentTypesById
    ]);
    let conflicting = [];
    if ('conflicting' in props.error) {
        conflicting = props.error.conflicting;
    }
    React.useEffect(()=>{
        const entryIds = state.entries.map((entry)=>entry.id);
        const conflictIds = conflicting.map((entry)=>entry.sys.id);
        if (conflictIds.every((id)=>entryIds.includes(id))) {
            return;
        }
        setState((state)=>({
                ...state,
                loading: true
            }));
        const query = {
            'sys.id[in]': conflictIds.join(',')
        };
        props.space.getEntries(query).then(({ items })=>{
            const entries = items.map((entry)=>({
                    id: entry.sys.id,
                    title: getTitle(entry),
                    href: props.getEntryURL(entry)
                }));
            setState({
                loading: false,
                entries
            });
        });
    }, [
        getTitle,
        state.entries,
        conflicting,
        props.space.getEntries,
        props.getEntryURL
    ]);
    return /*#__PURE__*/ React.createElement(List, {
        className: styles.errorList,
        testId: "validation-errors-uniqueness"
    }, /*#__PURE__*/ React.createElement(ListItem, {
        className: styles.entryLink
    }, state.loading ? /*#__PURE__*/ React.createElement("div", null, "Loading title for conflicting entry…") : state.entries.map((entry)=>/*#__PURE__*/ React.createElement(TextLink, {
            key: entry.id,
            href: entry.href,
            icon: /*#__PURE__*/ React.createElement(ExternalLinkIcon, null),
            alignIcon: "end",
            variant: "negative",
            target: "_blank",
            rel: "noopener noreferrer"
        }, entry.title))));
}
export function ValidationErrors(props) {
    const [errors, setErrors] = React.useState([]);
    React.useEffect(()=>{
        const onErrors = (errors)=>{
            setErrors(errors || []);
        };
        return props.field.onSchemaErrorsChanged(onErrors);
    }, [
        props.field
    ]);
    if (errors.length === 0) {
        return null;
    }
    return /*#__PURE__*/ React.createElement(List, {
        className: styles.errorList,
        testId: "validation-errors"
    }, errors.map((error, index)=>{
        return /*#__PURE__*/ React.createElement("li", {
            key: index,
            role: "status",
            "aria-roledescription": "field-locale-schema",
            "data-error-code": `entry.schema.${error.name}`,
            className: styles.errorItem
        }, /*#__PURE__*/ React.createElement(InfoCircleIcon, {
            variant: "negative"
        }), /*#__PURE__*/ React.createElement("div", {
            className: styles.errorMessage
        }, props.errorMessageOverride?.(error.message) ?? error.message, error.name === 'unique' && /*#__PURE__*/ React.createElement(UniquenessError, {
            error: error,
            space: props.space,
            localeCode: props.field.locale,
            defaultLocaleCode: props.locales.default,
            getEntryURL: props.getEntryURL
        })));
    }));
}
